@@ -1,20 +1,36 @@
-#
-# matrices Paul
-# M=number of valid vectors
-# Monotonicity always 'No'
-#
 
 
-PPE.BinBin <-function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, M=1000, Seed=1)
+PPE.BinBin <-function(pi1_1_, pi1_0_, pi_1_1, pi_1_0, pi0_1_, pi_0_1, M=10000, Seed=1)
 {
 
      
+#############################################################
+# diagnostics                                               #
+#############################################################
+ 
+vector_b <- matrix(data=c(1,  pi1_1_,  pi1_0_,  pi_1_1,  pi_1_0,  pi0_1_,  pi_0_1), ncol=1)    
+valid=((vector_b[4]+vector_b[5]+vector_b[7]<=1) & (vector_b[2]+vector_b[3]+vector_b[6]<=1))
+
+if (valid==TRUE){
+  PI1_1_=vector_b[2]
+  PI1_0_=vector_b[3]
+  PI_1_1=vector_b[4]
+  PI_1_0=vector_b[5]
+  PI0_1_=vector_b[6]
+  PI_0_1=vector_b[7]
+  PI_0_0=1-vector_b[4]-vector_b[5]-vector_b[7]
+  PI0_0_=1-vector_b[2]-vector_b[3]-vector_b[6]
+}
+if (valid !=TRUE){
+  stop('Input vector b not correctly defined')
+ }
+  
 #############################################################
 # Initialize                                                #
 #############################################################
 
 
-   R2_H_all<-Pi_f_all<-Grid<-I<-seed<-pi_f_all<- result<-POS<-H_Delta_T_all <-result<-Pe_all<-monotonicity_all<-Prediction_all<-NULL
+   R2_H_all<-Pi_f_all<-Grid<-I<-seed<-pi_f_all<- result<-POS<-H_Delta_T_all <-result<-Pe_all<-Prediction_all<-NULL
    pi0000<-pi0100<-pi0001<-pi0101<-pi1101<-pi1111<-pi0011<-pi0111<-pi1100<-pi0010<-pi1110<-pi0110<-pi1010<-pi1000<-pi1001<-pi1011<-RPE_all<-NULL
    I_Delta_T_Delta_S_all<-H_Delta_S_all<-support_delta_T_all<-combo_all<-pi_all<-index_all<-PPE_T_all<-PPE_all<-NULL
 
@@ -82,31 +98,6 @@ while (index < M){
 runs<-runs+1
 
 
-######################################################################################
-# Define vector b : this is a sampling step that allows to account for uncertainty.  #
-# Constraint added to have valid vectors                                             #
-######################################################################################
-
-
-   vector_b <- matrix(data=c(1, sample(size = 1, pi1_1_), sample(size = 1, pi1_0_), sample(size = 1, pi_1_1), 
-                        sample(size = 1, pi_1_0), sample(size = 1, pi0_1_), sample(size = 1, pi_0_1)), ncol=1) 
-
-   valid=((vector_b[4]+vector_b[6]+vector_b[7]<=1) & (vector_b[2]+vector_b[3]+vector_b[5]<=1))
-
-   if (valid==TRUE){
-
-   PI1_1_=vector_b[2]
-   PI1_0_=vector_b[3]
-   PI_1_1=vector_b[4]
-   PI_1_0=vector_b[5]
-   PI0_1_=vector_b[6]
-   PI_0_1=vector_b[7]
-#this is the corrected version
-   PI_0_0=1-vector_b[4]-vector_b[5]-vector_b[7]
-   PI0_0_=1-vector_b[2]-vector_b[3]-vector_b[6]
-
-
-
 #############################################################
 #  Apply Restrictions in sampling based on observed data    #
 #############################################################
@@ -204,8 +195,7 @@ runs<-runs+1
      H_Delta_T_all <-rbind(H_Delta_T_all, H_Delta_T)
      H_Delta_S_all <-rbind(H_Delta_S_all, H_Delta_S)          
      R2_H_all <- rbind(R2_H_all, R2_H)
-     monotonicity_all <- rbind(monotonicity_all, monotonicity)
-   
+    
          
      pi_all <- cbind(pi_all, pi) 
      index<-index+1
@@ -220,14 +210,14 @@ runs<-runs+1
       # colnames(Pi.Vectors) <- c("Pi_0000", "Pi_0100", "Pi_0001", "Pi_0101", "Pi_1101", "Pi_1111", "Pi_0011", 
       #                            "Pi_0111", "Pi_1100", "Pi_0010", "Pi_1110", "Pi_0110", "Pi_1010", "Pi_1000", "Pi_1001", "Pi_1011") 
     
-    }#valid=true
+  
    }#pi_r>0
    }#while index<M
 
 print(runs)
 
 #Pi.Vectors= Pi.Vectors terugzetten
-fit<-data.frame(index=as.numeric(index_all),PPE=as.numeric(PPE_all),RPE=as.numeric(RPE_all), Monotonicity=as.character(monotonicity_all),
+fit<-data.frame(index=as.numeric(index_all),PPE=as.numeric(PPE_all),RPE=as.numeric(RPE_all), 
                 PPE_T=as.numeric(PPE_T_all), R2_H=as.numeric(R2_H_all), H_Delta_T=as.numeric(H_Delta_T_all),
                 H_Delta_S=as.numeric(H_Delta_S_all), I_Delta_T_Delta_S=as.numeric(I_Delta_T_Delta_S_all))
 class(fit)<-"PPE.BinBin"
